'use strict';

var view = require('@codemirror/view');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');

// Tokyo Night Day theme color definitions
const base00 = '#e1e2e7', // Background
base01 = '#3760bf', // Foreground, used in several elements like cursor and variable names
base02 = '#99a7df', // Selection Match
base03 = '#848cb5', // Comment color
base04 = '#3760bf', // Cursor color
base05 = '#587539', // Green used for strings and regex
base06 = '#5f5faf11', // Line highlight
base07 = '#007197', // Blue used for keywords, type names, and operators
base08 = '#b15c00', // Orange used for numbers and headings
base09 = '#f52a65', // Red for invalid elements
darkBackground = base00, highlightBackground = base06, background = base00, // Main background
tooltipBackground = base01, selection = base02, cursor = base04; // Cursor color
/// The editor theme styles for Tokyo Night Day.
const tokyoNightDayTheme = view.EditorView.theme({
    '&': {
        color: base01,
        backgroundColor: background
    },
    '.cm-content': {
        caretColor: cursor
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: cursor
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection
    },
    '.cm-panels': {
        backgroundColor: darkBackground,
        color: base03
    },
    '.cm-panels.cm-panels-top': {
        borderBottom: '2px solid black'
    },
    '.cm-panels.cm-panels-bottom': {
        borderTop: '2px solid black'
    },
    '.cm-searchMatch': {
        backgroundColor: base02, // Lighter shade for search matches
        outline: `1px solid ${base03}`
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: base06
    },
    '.cm-activeLine': {
        backgroundColor: highlightBackground
    },
    '.cm-selectionMatch': {
        backgroundColor: base05
    },
    '&.cm-focused .cm-matchingBracket, &.cm-focused .cm-nonmatchingBracket': {
        outline: `1px solid ${base03}`
    },
    '&.cm-focused .cm-matchingBracket': {
        backgroundColor: base06
    },
    '.cm-gutters': {
        backgroundColor: darkBackground,
        color: base03,
        border: 'none'
    },
    '.cm-activeLineGutter': {
        backgroundColor: highlightBackground
    },
    '.cm-foldPlaceholder': {
        backgroundColor: 'transparent',
        border: 'none',
        color: base04
    },
    '.cm-tooltip': {
        border: 'none',
        backgroundColor: tooltipBackground
    },
    '.cm-tooltip .cm-tooltip-arrow:before': {
        borderTopColor: 'transparent',
        borderBottomColor: 'transparent'
    },
    '.cm-tooltip .cm-tooltip-arrow:after': {
        borderTopColor: tooltipBackground,
        borderBottomColor: tooltipBackground
    },
    '.cm-tooltip-autocomplete': {
        '& > ul > li[aria-selected]': {
            backgroundColor: highlightBackground,
            color: base03
        }
    }
}, { dark: false });
/// The highlighting style for code in the Tokyo Night Day theme.
const tokyoNightDayHighlightStyle = language.HighlightStyle.define([
    { tag: highlight.tags.keyword, color: base07 },
    { tag: [highlight.tags.name, highlight.tags.deleted, highlight.tags.character, highlight.tags.macroName], color: base01 },
    { tag: [highlight.tags.propertyName], color: base01 },
    { tag: [highlight.tags.processingInstruction, highlight.tags.string, highlight.tags.inserted, highlight.tags.special(highlight.tags.string)], color: base05 },
    { tag: [highlight.tags.function(highlight.tags.variableName), highlight.tags.labelName], color: base01 },
    { tag: [highlight.tags.color, highlight.tags.constant(highlight.tags.name), highlight.tags.standard(highlight.tags.name)], color: base01 },
    { tag: [highlight.tags.definition(highlight.tags.name), highlight.tags.separator], color: base01 },
    { tag: [highlight.tags.className], color: base01 },
    { tag: [highlight.tags.number, highlight.tags.changed, highlight.tags.annotation, highlight.tags.modifier, highlight.tags.self, highlight.tags.namespace], color: base08 },
    { tag: [highlight.tags.typeName], color: base07 },
    { tag: [highlight.tags.operator, highlight.tags.operatorKeyword], color: base07 },
    { tag: [highlight.tags.url, highlight.tags.escape, highlight.tags.regexp, highlight.tags.link], color: base05 },
    { tag: [highlight.tags.meta, highlight.tags.comment], color: base03 },
    { tag: highlight.tags.tagName, color: base07 },
    { tag: highlight.tags.strong, fontWeight: 'bold' },
    { tag: highlight.tags.emphasis, fontStyle: 'italic' },
    { tag: highlight.tags.link, textDecoration: 'underline' },
    { tag: highlight.tags.heading, fontWeight: 'bold', color: base08 },
    { tag: [highlight.tags.atom, highlight.tags.bool, highlight.tags.special(highlight.tags.variableName)], color: base01 },
    { tag: highlight.tags.invalid, color: base09 },
    { tag: highlight.tags.strikethrough, textDecoration: 'line-through' }
]);
/// Extension to enable the Tokyo Night Day theme (both the editor theme and the highlight style).
const tokyoNightDay = [
    tokyoNightDayTheme,
    language.syntaxHighlighting(tokyoNightDayHighlightStyle)
];

exports.tokyoNightDay = tokyoNightDay;
exports.tokyoNightDayHighlightStyle = tokyoNightDayHighlightStyle;
exports.tokyoNightDayTheme = tokyoNightDayTheme;
