import { EditorView } from '@codemirror/view';
import { HighlightStyle, syntaxHighlighting } from '@codemirror/language';
import { tags } from '@lezer/highlight';

// Tokyo Night Day theme color definitions
const base00 = '#e1e2e7', // Background
base01 = '#3760bf', // Foreground, used in several elements like cursor and variable names
base02 = '#99a7df', // Selection Match
base03 = '#848cb5', // Comment color
base04 = '#3760bf', // Cursor color
base05 = '#587539', // Green used for strings and regex
base06 = '#5f5faf11', // Line highlight
base07 = '#007197', // Blue used for keywords, type names, and operators
base08 = '#b15c00', // Orange used for numbers and headings
base09 = '#f52a65', // Red for invalid elements
darkBackground = base00, highlightBackground = base06, background = base00, // Main background
tooltipBackground = base01, selection = base02, cursor = base04; // Cursor color
/// The editor theme styles for Tokyo Night Day.
const tokyoNightDayTheme = /*@__PURE__*/EditorView.theme({
    '&': {
        color: base01,
        backgroundColor: background
    },
    '.cm-content': {
        caretColor: cursor
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: cursor
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection
    },
    '.cm-panels': {
        backgroundColor: darkBackground,
        color: base03
    },
    '.cm-panels.cm-panels-top': {
        borderBottom: '2px solid black'
    },
    '.cm-panels.cm-panels-bottom': {
        borderTop: '2px solid black'
    },
    '.cm-searchMatch': {
        backgroundColor: base02, // Lighter shade for search matches
        outline: `1px solid ${base03}`
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: base06
    },
    '.cm-activeLine': {
        backgroundColor: highlightBackground
    },
    '.cm-selectionMatch': {
        backgroundColor: base05
    },
    '&.cm-focused .cm-matchingBracket, &.cm-focused .cm-nonmatchingBracket': {
        outline: `1px solid ${base03}`
    },
    '&.cm-focused .cm-matchingBracket': {
        backgroundColor: base06
    },
    '.cm-gutters': {
        backgroundColor: darkBackground,
        color: base03,
        border: 'none'
    },
    '.cm-activeLineGutter': {
        backgroundColor: highlightBackground
    },
    '.cm-foldPlaceholder': {
        backgroundColor: 'transparent',
        border: 'none',
        color: base04
    },
    '.cm-tooltip': {
        border: 'none',
        backgroundColor: tooltipBackground
    },
    '.cm-tooltip .cm-tooltip-arrow:before': {
        borderTopColor: 'transparent',
        borderBottomColor: 'transparent'
    },
    '.cm-tooltip .cm-tooltip-arrow:after': {
        borderTopColor: tooltipBackground,
        borderBottomColor: tooltipBackground
    },
    '.cm-tooltip-autocomplete': {
        '& > ul > li[aria-selected]': {
            backgroundColor: highlightBackground,
            color: base03
        }
    }
}, { dark: false });
/// The highlighting style for code in the Tokyo Night Day theme.
const tokyoNightDayHighlightStyle = /*@__PURE__*/HighlightStyle.define([
    { tag: tags.keyword, color: base07 },
    { tag: [tags.name, tags.deleted, tags.character, tags.macroName], color: base01 },
    { tag: [tags.propertyName], color: base01 },
    { tag: [tags.processingInstruction, tags.string, tags.inserted, /*@__PURE__*/tags.special(tags.string)], color: base05 },
    { tag: [/*@__PURE__*/tags.function(tags.variableName), tags.labelName], color: base01 },
    { tag: [tags.color, /*@__PURE__*/tags.constant(tags.name), /*@__PURE__*/tags.standard(tags.name)], color: base01 },
    { tag: [/*@__PURE__*/tags.definition(tags.name), tags.separator], color: base01 },
    { tag: [tags.className], color: base01 },
    { tag: [tags.number, tags.changed, tags.annotation, tags.modifier, tags.self, tags.namespace], color: base08 },
    { tag: [tags.typeName], color: base07 },
    { tag: [tags.operator, tags.operatorKeyword], color: base07 },
    { tag: [tags.url, tags.escape, tags.regexp, tags.link], color: base05 },
    { tag: [tags.meta, tags.comment], color: base03 },
    { tag: tags.tagName, color: base07 },
    { tag: tags.strong, fontWeight: 'bold' },
    { tag: tags.emphasis, fontStyle: 'italic' },
    { tag: tags.link, textDecoration: 'underline' },
    { tag: tags.heading, fontWeight: 'bold', color: base08 },
    { tag: [tags.atom, tags.bool, /*@__PURE__*/tags.special(tags.variableName)], color: base01 },
    { tag: tags.invalid, color: base09 },
    { tag: tags.strikethrough, textDecoration: 'line-through' }
]);
/// Extension to enable the Tokyo Night Day theme (both the editor theme and the highlight style).
const tokyoNightDay = [
    tokyoNightDayTheme,
    /*@__PURE__*/syntaxHighlighting(tokyoNightDayHighlightStyle)
];

export { tokyoNightDay, tokyoNightDayHighlightStyle, tokyoNightDayTheme };
